@@ -139,7 +139,7 @@ their interior areas filled.
 
 =begin HTML
 
-<p><img src="http://github.com/gphat/chart-clicker-examples/raw/master/area/area.png" width="500" height="250" alt="Area Chart" /></p>
+<p><img src="http://www.onemogin.com/clicker/chart-clicker-examples/area/area.png" width="500" height="250" alt="Area Chart" /></p>
 
 =end HTML
 
